<?php
/**
Helper functions for combining multiple page.
  
Public functions:
  set_onepage_content($add, $slug, ...)
    where $add is true, if the content of the $slugs is to be added to the current page's content,
    or false, if the content shall be replaced
  set_onepage_content_from_field($add, $fieldname, $separatorslug)
    where the page slugs need to be specified in the (custom/special) field $fieldname, separated by comma.
    If a $separatorslug is given, the content of this page is inserted between the other contents.
  return_onepage_count()
    returns the number of content parts
  return_onepage_slug()
    returns the current content part slug (optional parameter $num outputs a specific part's slug)
  get_onepage_content()
    outputs the next content part (optional parameter $num to output a specific part)
  has_onepage_content()
    returns true, if there are more content parts.
    
You need to call one of the set_onepage_content functions before any other function in the theme, 
esp. before get_header/get_i18n_header.
Afterwards you can call get_page_content() for the whole content or get_onepage_content() for the parts.
*/

# get correct id for plugin
$thisfile = basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, 
	'I18n OnePage', 	
	'0.2', 		
	'Martin Vlcek',
	'http://mvlcek.bplaced.net', 
	'Helper functions for combining multiple pages into one page, e.g. for single-page themes',
	'',
	''  
);

$onepage_index = 0;
$onepage_slugs = array();
$onepage_contents = array();

function return_onepage_raw_content($slug) {
	if (function_exists('return_i18n_page_data')) {
		$pagedata = return_i18n_page_data($slug);
		return (string) $pagedata->content;
	} else {
		return returnPageContent($slug, 'content', true, true);
	}
}

function set_onepage_content($add, $slugs) {
	global $content, $onepage_contents, $onepage_slugs;
	$currentslug = return_page_slug();
	if (!$add) {
		$content = '';
	} else {
		$onepage_slugs[] = $currentslug;
		$onepage_contents[] = $content;
	}
	if (!is_array($slugs)) {
		$slugs = func_get_args();
		array_shift($slugs);
	}
	foreach ($slugs as $slug) {
		if (!$add || $slug != $currentslug) {
			$c = return_onepage_raw_content($slug);
			$content .= $c;
			$onepage_slugs[] = $slug;
			$onepage_contents[] = $c;
		}
	}
}

function set_onepage_content_from_field($add, $fieldname, $separatorslug=null) {
	global $content, $data_index, $onepage_contents, $onepage_slugs;
	$currentslug = return_page_slug();
	if (!$add) {
		$content = '';
	} else {
		$onepage_slugs[] = $currentslug;
		$onepage_contents[] = $content;
	}
	$slugs = preg_split("/\s*[,]\s*/", (string) $data_index->$fieldname);
	if ($separatorslug) {
		$separatorcontent = return_onepage_raw_content($separatorslug);
	}
	foreach ($slugs as $slug) {
		if (!$add || $slug != $currentslug) {
			if ($content != '' && $separatorslug) {
			  $content .= $separatorcontent;
		  }
			$c = return_onepage_raw_content($slug);
			$content .= $c;
			$onepage_slugs[] = $slug;
			$onepage_contents[] = $c;
		}
	}
}

function return_onepage_count() {
	global $onepage_contents;
	return count($onepage_contents);
}

function has_onepage_content($num=null) {
	global $onepage_index, $onepage_contents;
	$index = $num !== null ? $num : $onepage_index;
	return $index >= 0 && $index < count($onepage_contents);
}

function return_onepage_slug($num=null) {
	global $onepage_index, $onepage_slugs;
	$index = $num !== null ? $num : $onepage_index;
	return $index >= 0 && $index < count($onepage_slugs) ? $onepage_slugs[$index] : null;
}

function get_onepage_content($num=null) {
	global $onepage_index, $onepage_contents, $content;
	if ($num !== null && $num >= 0 && $num < count($onepage_contents)) {
		$content = $onepage_contents[$num];
		get_page_content();
		return true;
	} else if ($num === null && $onepage_index < count($onepage_contents)) {
		$content = $onepage_contents[$onepage_index];
		get_page_content();
		$onepage_index++;
		return true;
	}
	return false;
}